# Assertion


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**tuple_key** | [**AssertionTupleKey**](AssertionTupleKey.md) |  | 
**expectation** | **bool** |  | 
**contextual_tuples** | [**list[TupleKey]**](TupleKey.md) |  | [optional] 
**context** | **object** | Additional request context that will be used to evaluate any ABAC conditions encountered in the query evaluation. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


